@@ -23,10 +23,10 @@ from enum import Enum
 if typing.TYPE_CHECKING:
     from typing import Dict, List, Optional, Union
     from datetime import datetime
-    from ask_sdk_model.interfaces.amazonpay.model.v1.seller_order_attributes import SellerOrderAttributes
-    from ask_sdk_model.interfaces.amazonpay.model.v1.payment_action import PaymentAction
-    from ask_sdk_model.interfaces.amazonpay.model.v1.authorize_attributes import AuthorizeAttributes
-    from ask_sdk_model.interfaces.amazonpay.model.v1.provider_attributes import ProviderAttributes
+    from ask_sdk_model.interfaces.amazonpay.model.v1.authorize_attributes import AuthorizeAttributesV1
+    from ask_sdk_model.interfaces.amazonpay.model.v1.payment_action import PaymentActionV1
+    from ask_sdk_model.interfaces.amazonpay.model.v1.seller_order_attributes import SellerOrderAttributesV1
+    from ask_sdk_model.interfaces.amazonpay.model.v1.provider_attributes import ProviderAttributesV1
 
 
 class ChargeAmazonPay(object):
@@ -72,7 +72,7 @@ class ChargeAmazonPay(object):
     supports_multiple_types = False
 
     def __init__(self, consent_token=None, seller_id=None, billing_agreement_id=None, payment_action=None, authorize_attributes=None, seller_order_attributes=None, provider_attributes=None):
-        # type: (Optional[str], Optional[str], Optional[str], Optional[PaymentAction], Optional[AuthorizeAttributes], Optional[SellerOrderAttributes], Optional[ProviderAttributes]) -> None
+        # type: (Optional[str], Optional[str], Optional[str], Optional[PaymentActionV1], Optional[AuthorizeAttributesV1], Optional[SellerOrderAttributesV1], Optional[ProviderAttributesV1]) -> None
         """Charge Amazon Pay Request Object
 
         :param consent_token: Authorization token that contains the permissions consented to by the user.
